@@ -117,6 +117,7 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "KN", FeatureRemark, Feature::FamilyArea, Feature::Available },
     { "A", "LS", FeatureRemark, Feature::PowerSockets, Feature::Available },
     { "A", "MN", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "MP", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "NF", FeatureRemark, Feature::BikeStorage, Feature::Unavailable },
     { "A", "OA", FeatureRemark, Feature::WheelchairAccessible, Feature::Conditional },
     { "A", "OC", FeatureRemark, Feature::WheelchairAccessibleToilet, Feature::Available },
@@ -128,11 +129,13 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "SA", FeatureRemark, Feature::ToddlerArea, Feature::Limited },
     { "A", "SI", FeatureRemark, Feature::WheelchairAccessible, Feature::Limited },
     { "A", "SN", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "TM", FeatureRemark, Feature::Restaurant, Feature::Limited },
     { "A", "TO", FeatureRemark, Feature::Toilet, Feature::Available },
     { "A", "UA", FeatureRemark, Feature::BusinessArea, Feature::Available },
     { "A", "WI", FeatureRemark, Feature::WiFi, Feature::Available },
     { "A", "WV", FeatureRemark, Feature::WiFi, Feature::Available },
     { "A", "bf", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "bg", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "hz", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ia", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ic", FeatureRemark, Feature::Restaurant, Feature::Available },
